@@ -23,7 +23,7 @@ use std::hash::Hash;
 /// assert_eq!(dice.probability(&"6"), Probability::new(0, 6));
 /// ```
 #[derive(Clone, Eq, Debug)]
-#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub struct CardDeck<C>
 where
     C: Eq + Hash,
@@ -267,12 +267,12 @@ where
     /// use stochasta::Probability;
     /// use stochasta::CardDeck;
     ///
-    /// let coin = CardDeck::from(vec!["head", "tails"]);
+    /// let coin = CardDeck::from(vec!["heads", "tails"]);
     /// assert_eq!(
     ///     coin.probabilities(),
     ///     HashMap::from([
-    ///         (&"head",  Probability::new(1, 2)),
-    ///         (&"tails", Probability::new(1, 2))
+    ///         (&"heads", Probability::new(1, 2)),
+    ///         (&"tails", Probability::new(1, 2)),
     ///     ])
     /// );
     /// ```
@@ -311,8 +311,7 @@ where
     /// ```
     /// use stochasta::CardDeck;
     ///
-    /// let card = "demo";
-    /// let mut deck = CardDeck::from(vec![1, 3, 3]);
+    /// let deck = CardDeck::from(vec![1, 3, 3]);
     ///
     /// assert_eq!(deck.count(&1), 1);
     /// assert_eq!(deck.count(&3), 2);
